pub struct HomeserverToken;Expand description
Authentication is required, and can only be performed by a homeserver sending a request to an
appservice, by including a homeserver access token in the Authentication http header, or an
access_token query parameter.
Using the query parameter is deprecated since Matrix 1.11.