pub struct RegistrationInit {
pub id: String,
pub url: Option<String>,
pub as_token: String,
pub hs_token: String,
pub sender_localpart: String,
pub namespaces: Namespaces,
pub rate_limited: Option<bool>,
pub protocols: Option<Vec<String>>,
}Expand description
Initial set of fields of Registration.
This struct will not be updated even if additional fields are added to Registration in a new
(non-breaking) release of the Matrix specification.
Used for appservice registration.
Fields
id: StringA unique, user - defined ID of the application service which will never change.
url: Option<String>The URL for the application service.
Optionally set to null if no traffic is required.
as_token: StringA unique token for application services to use to authenticate requests to Homeservers.
hs_token: StringA unique token for Homeservers to use to authenticate requests to application services.
sender_localpart: StringThe localpart of the user associated with the application service.
namespaces: NamespacesA list of users, aliases and rooms namespaces that the application service controls.
rate_limited: Option<bool>Whether requests from masqueraded users are rate-limited.
The sender is excluded.
protocols: Option<Vec<String>>The external protocols which the application service provides (e.g. IRC).